====
twip
====


Tweet Impact Predictor


Description
===========

A LONGER DESCRIPTION OF YOUR PROJECT GOES HERE...


Note
====

This project has been set up using PyScaffold 2.4.4. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
